/*
	*
	* This file is a part of IonShell.
	* IonShell is the Desktop Shell App for Ion DE
	* Copyright 2020 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* ( at your option ) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#include <QDebug>
#include <QWindow>

#include "qwayland-wayfire-shell-unstable-v2.h"

#include "DesQLayerShell.hpp"
#include "DesQWlGlobal.hpp"
#include "DesQHotSpot.hpp"
#include "DesQHotSpotImpl.hpp"

// TODO : A slide down animation to hide the dock

DesQHotSpotPrivate::DesQHotSpotPrivate( QScreen *screen, zwf_shell_manager_v2 *wfShell, DesQHotSpot *ptr ) : q_ptr( ptr ) {

	m_wfOutput = zwf_shell_manager_v2_get_wf_output( wfShell, DesQWayland::getWlOutput( screen ) );
}

void DesQHotSpotPrivate::createHotspot( int pos, uint height, uint duration ) {

	init( zwf_output_v2_create_hotspot( m_wfOutput, pos, height, duration ) );
}

void DesQHotSpotPrivate::destroy() {

	if ( object() ) {
		zwf_hotspot_v2_destroy( object() );
	}
}

void DesQHotSpotPrivate::zwf_hotspot_v2_enter() {

	Q_Q( DesQHotSpot );
	emit q->enteredHotspot();
}

void DesQHotSpotPrivate::zwf_hotspot_v2_leave() {

	Q_Q( DesQHotSpot );
	emit q->leftHotspot();
}

DesQHotSpot::DesQHotSpot( QScreen *screen, zwf_shell_manager_v2 *wfShell, QObject *parent ) : QObject( parent ) {

	d_ptr = new DesQHotSpotPrivate( screen, wfShell, this );
}

void DesQHotSpot::createHotspot( DesQHotSpot::Position pos, uint height, uint duration ) {

	Q_D( DesQHotSpot );
	d->createHotspot( pos, height, duration );
}

void DesQHotSpot::destroy() {

	Q_D( DesQHotSpot );
	d->destroy();
}

void DesQHotSpot::zwf_hotspot_v2_enter() {

	Q_D( DesQHotSpot );
	d->zwf_hotspot_v2_enter();
}

void DesQHotSpot::zwf_hotspot_v2_leave() {

	Q_D( DesQHotSpot );
	d->zwf_hotspot_v2_leave();
}
